@@ -50,16 +50,16 @@ class TransactionSet:
 				)
 
 				for index, adjustment in enumerate(service.adjustments):
-					datum[f'adj_{index}_group'] = adjustment.group_code
+					datum[f'adj_{index}_group'] = adjustment.group_code.code
 					datum[f'adj_{index}_code'] = adjustment.reason_code.code
 					datum[f'adj_{index}_amount'] = adjustment.amount
 
 				for index, reference in enumerate(service.references):
-					datum[f'ref_{index}_code'] = reference.qualifier.code
+					datum[f'ref_{index}_qual'] = reference.qualifier.code
 					datum[f'ref_{index}_value'] = reference.value
 
 				for index, remark in enumerate(service.remarks):
-					datum[f'rem_{index}_group'] = remark.qualifier
+					datum[f'rem_{index}_qual'] = remark.qualifier.code
 					datum[f'rem_{index}_code'] = remark.code.code
 
 				data.append(datum)
@@ -90,12 +90,16 @@ class TransactionSet:
 			end_date = claim.claim_statement_period_end.date
 
 		datum = {
-			'claim_index': claim.claim.index,
+			'marker': claim.claim.marker,
 			'patient': claim.patient.name,
-			'code': service.service.service_code,
-			'units': service.service.units,
+			'code': service.service.code,
+			'modifier': service.service.modifier,
+			'qualifier': service.service.qualifier,
+			'allowed_units': service.service.allowed_units,
+			'billed_units': service.service.billed_units,
 			'transaction_date': financial_information.transaction_date,
 			'charge_amount': service.service.charge_amount,
+			'allowed_amount': service.allowed_amount,
 			'paid_amount': service.service.paid_amount,
 			'payer': payer.organization.name,
 			'start_date': start_date,
